@@ -1,11 +1,11 @@
 /*  File src/wtMHproposals.c in package ergm.count, part of the Statnet suite
- *  of packages for network analysis, http://statnet.org .
+ *  of packages for network analysis, https://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) at
- *  http://statnet.org/attribution
+ *  https://statnet.org/attribution
  *
- *  Copyright 2008-2018 Statnet Commons
+ *  Copyright 2008-2019 Statnet Commons
  */
 #include "wtMHproposals.h"
 
@@ -19,7 +19,7 @@
 
  Default MH algorithm for Poisson-reference ERGM
 *********************/
-void MH_Poisson(WtMHproposal *MHp, WtNetwork *nwp)  {  
+WtMH_P_FN(MH_Poisson){  
   double oldwt;
   
   if(MHp->ntoggles == 0) { // Initialize Poisson 
@@ -46,7 +46,7 @@ void MH_Poisson(WtMHproposal *MHp, WtNetwork *nwp)  {
  MH algorithm for Poisson-reference ERGM with zero-inflating terms.
  Ocassionally proposes jumps to 0.
 *********************/
-void MH_ZIPoisson(WtMHproposal *MHp, WtNetwork *nwp)  {  
+WtMH_P_FN(MH_ZIPoisson){  
   double oldwt, p0=MHp->inputs[0];
   
   if(MHp->ntoggles == 0) { // Initialize Poisson 
@@ -82,7 +82,7 @@ void MH_ZIPoisson(WtMHproposal *MHp, WtNetwork *nwp)  {
  MH algorithm for Poisson-reference ERGM with zero-inflating terms.
  Ocassionally proposes jumps to 0.
 *********************/
-void MH_PoissonTNT(WtMHproposal *MHp, WtNetwork *nwp)  {  
+WtMH_P_FN(MH_PoissonTNT){  
   Edge nedges=nwp->nedges;
   double oldwt;
   static double comp, odds;
@@ -132,7 +132,7 @@ void MH_PoissonTNT(WtMHproposal *MHp, WtNetwork *nwp)  {
 
  Missing data MH algorithm for Poisson-reference ERGM on bipartite networks.
 *********************/
-void MH_PoissonNonObserved(WtMHproposal *MHp, WtNetwork *nwp)  {  
+WtMH_P_FN(MH_PoissonNonObserved){  
   Edge nmissing = MHp->inputs[0];
 
   if(MHp->ntoggles == 0) { /* Initialize */
@@ -172,7 +172,7 @@ void MH_PoissonNonObserved(WtMHproposal *MHp, WtNetwork *nwp)  {
 
  Default MH algorithm for binomial-reference ERGM
 *********************/
-void MH_Binomial(WtMHproposal *MHp, WtNetwork *nwp)  {  
+WtMH_P_FN(MH_Binomial){  
   double oldwt;
   static unsigned int trials;
   
@@ -209,7 +209,7 @@ void MH_Binomial(WtMHproposal *MHp, WtNetwork *nwp)  {
 
  Missing data MH algorithm for binomial-reference ERGM on bipartite networks.
 *********************/
-void MH_BinomialNonObserved(WtMHproposal *MHp, WtNetwork *nwp)  {  
+WtMH_P_FN(MH_BinomialNonObserved){  
   Edge nmissing = MHp->inputs[1];
 
   static unsigned int trials;
@@ -260,7 +260,7 @@ void MH_BinomialNonObserved(WtMHproposal *MHp, WtNetwork *nwp)  {
 
  Default MH algorithm for geometric-reference ERGM
 *********************/
-void MH_Geometric(WtMHproposal *MHp, WtNetwork *nwp)  {  
+WtMH_P_FN(MH_Geometric){  
   double oldwt;
   
   if(MHp->ntoggles == 0) { // Initialize Geometric 
@@ -293,7 +293,7 @@ void MH_Geometric(WtMHproposal *MHp, WtNetwork *nwp)  {
 
  Missing data MH algorithm for geometric-reference ERGM.
 *********************/
-void MH_GeometricNonObserved(WtMHproposal *MHp, WtNetwork *nwp)  {  
+WtMH_P_FN(MH_GeometricNonObserved){  
   Edge nmissing = MHp->inputs[0];
 
   if(MHp->ntoggles == 0) { /* Initialize */
